@@ -1,6 +1,6 @@
 /* -*- mode: C; c-basic-offset: 4 -*-
  * pyorbit - a Python language mapping for the ORBit2 CORBA ORB
- * Copyright (C) 2002  James Henstridge <james@daa.com.au>
+ * Copyright (C) 2002-2003  James Henstridge <james@daa.com.au>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,6 +20,9 @@
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
+
+#define PY_SIZE_T_CLEAN
+
 #include "pyorbit-private.h"
 #include <structmember.h>
 
@@ -35,7 +38,7 @@ pycorba_struct_dealloc(PyObject *self)
 static int
 pycorba_struct_init(PyObject *self, PyObject *args, PyObject *kwargs)
 {
-    gint len, i;
+    Py_ssize_t len, i;
     PyObject *pytc;
     CORBA_TypeCode tc;
 
@@ -138,7 +141,7 @@ pycorba_union_dealloc(PyCORBA_Union *self)
 static int
 pycorba_union_init(PyCORBA_Union *self, PyObject *args, PyObject *kwargs)
 {
-    gint len;
+    Py_ssize_t len;
     PyObject *pytc;
     CORBA_TypeCode tc;
 
@@ -172,7 +175,7 @@ pycorba_union_init(PyCORBA_Union *self, PyObject *args, PyObject *kwargs)
 	self->_v = value;
 	Py_INCREF(self->_v);
     } else if (len == 0 && PyDict_Size(kwargs) == 1) {
-	int pos = 0;
+	Py_ssize_t pos = 0;
 	PyObject *key, *val, *discriminator;
 	const gchar *keyname;
 
