@@ -20,6 +20,9 @@
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
+
+#define PY_SIZE_T_CLEAN
+
 #include "pyorbit-private.h"
 
 static void
@@ -157,7 +160,7 @@ static PyObject *
 pycorba_typecode_get_subtypes(PyCORBA_TypeCode *self, void *closure)
 {
     PyObject *ret;
-    gint i;
+    Py_ssize_t i;
 
     if (self->tc->kind != CORBA_tk_struct &&
 	self->tc->kind != CORBA_tk_except &&
@@ -211,7 +214,7 @@ static PyObject *
 pycorba_typecode_get_subnames(PyCORBA_TypeCode *self, void *closure)
 {
     PyObject *ret;
-    gint i;
+    Py_ssize_t i;
 
     if (self->tc->kind != CORBA_tk_struct &&
 	self->tc->kind != CORBA_tk_except &&
